feast.types.Field_pb2 — Feast 0.3.2 documentation

# Source code for feast.types.Field_pb2

    # -*- coding: utf-8 -*-
    # Generated by the protocol buffer compiler.  DO NOT EDIT!
    # source: feast/types/Field.proto

    import sys
    _b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
    from google.protobuf import descriptor as _descriptor
    from google.protobuf import message as _message
    from google.protobuf import reflection as _reflection
    from google.protobuf import symbol_database as _symbol_database
    # @@protoc_insertion_point(imports)

    _sym_db = _symbol_database.Default()

    from feast.types import Value_pb2 as feast_dot_types_dot_Value__pb2

    DESCRIPTOR = _descriptor.FileDescriptor(
      name='feast/types/Field.proto',
      package='feast.types',
      syntax='proto3',
      serialized_options=_b('\n\013feast.typesB\nFieldProtoZ0github.com/gojek/feast/sdk/go/protos/feast/types'),
      serialized_pb=_b('\n\x17\x66\x65\x61st/types/Field.proto\x12\x0b\x66\x65\x61st.types\x1a\x17\x66\x65\x61st/types/Value.proto\"8\n\x05\x46ield\x12\x0c\n\x04name\x18\x01 \x01(\t\x12!\n\x05value\x18\x02 \x01(\x0b\x32\x12.feast.types.ValueBK\n\x0b\x66\x65\x61st.typesB\nFieldProtoZ0github.com/gojek/feast/sdk/go/protos/feast/typesb\x06proto3')
      ,
      dependencies=[feast_dot_types_dot_Value__pb2.DESCRIPTOR,])

    _FIELD = _descriptor.Descriptor(
      name='Field',
      full_name='feast.types.Field',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      fields=[
        _descriptor.FieldDescriptor(
          name='name', full_name='feast.types.Field.name', index=0,
          number=1, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=_b("").decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
          name='value', full_name='feast.types.Field.value', index=1,
          number=2, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=65,
      serialized_end=121,
    )

    _FIELD.fields_by_name['value'].message_type = feast_dot_types_dot_Value__pb2._VALUE
    DESCRIPTOR.message_types_by_name['Field'] = _FIELD
    _sym_db.RegisterFileDescriptor(DESCRIPTOR)

    Field = _reflection.GeneratedProtocolMessageType('Field', (_message.Message,), {
      'DESCRIPTOR' : _FIELD,
      '__module__' : 'feast.types.Field_pb2'
      # @@protoc_insertion_point(class_scope:feast.types.Field)
      })
    _sym_db.RegisterMessage(Field)

    DESCRIPTOR._options = None
    # @@protoc_insertion_point(module_scope)